@@ -19,20 +19,21 @@ from . import (
     CoverageAnalyzeTargetsConfig,
     expand_indexes,
     format_arc,
+    format_line,
     read_report,
 )
 
 
 class CoverageAnalyzeTargetsExpandConfig(CoverageAnalyzeTargetsConfig):
     """Configuration for the `coverage analyze targets expand` command."""
-    def __init__(self, args):  # type: (t.Any) -> None
+    def __init__(self, args: t.Any) -> None:
         super().__init__(args)
 
-        self.input_file = args.input_file  # type: str
-        self.output_file = args.output_file  # type: str
+        self.input_file: str = args.input_file
+        self.output_file: str = args.output_file
 
 
-def command_coverage_analyze_targets_expand(args):  # type: (CoverageAnalyzeTargetsExpandConfig) -> None
+def command_coverage_analyze_targets_expand(args: CoverageAnalyzeTargetsExpandConfig) -> None:
     """Expand target names in an aggregated coverage file."""
     host_state = prepare_profiles(args)  # coverage analyze targets expand
 
@@ -43,7 +44,7 @@ def command_coverage_analyze_targets_expand(args):  # type: (CoverageAnalyzeTarg
 
     report = dict(
         arcs=expand_indexes(covered_path_arcs, covered_targets, format_arc),
-        lines=expand_indexes(covered_path_lines, covered_targets, str),
+        lines=expand_indexes(covered_path_lines, covered_targets, format_line),
     )
 
     if not args.explain:
